@@ -29,6 +29,25 @@ def test_optional():
     assert "User: Camila" in result.output
 
 
+def test_optional_tuple():
+    app = typer.Typer()
+
+    @app.command()
+    def opt(number: Optional[Tuple[int, int]] = None):
+        if number:
+            print(f"Number: {number}")
+        else:
+            print("No number")
+
+    result = runner.invoke(app)
+    assert result.exit_code == 0
+    assert "No number" in result.output
+
+    result = runner.invoke(app, ["--number", "4", "2"])
+    assert result.exit_code == 0
+    assert "Number: (4, 2)" in result.output
+
+
 def test_no_type():
     app = typer.Typer()
 
